@@ -27,11 +27,24 @@ function install_configure_etcd {
     # and <controller_ip> appropriately.
     if $CALICO_COMPUTE_ONLY; then
 	# Configure an etcd proxy.
-	sudo sed -i "s/exec.*/exec \/usr\/bin\/etcd --proxy on \
+	if test -f /etc/init/etcd.conf; then
+	    # upstart configuration
+	    sudo sed -i "s/exec.*/exec \/usr\/bin\/etcd --proxy on \
   --initial-cluster \"$SERVICE_HOST=http:\/\/$SERVICE_HOST:2380\"/" /etc/init/etcd.conf
+	else
+	    # systemd configuration
+	    etcd_cfg=`mktemp -t etcd.XXXXXX`
+	    cat >${etcd_cfg} <<EOF
+ETCD_PROXY=on
+ETCD_INITIAL_CLUSTER="$SERVICE_HOST=http://$SERVICE_HOST:2380"
+EOF
+	    sudo mv -f ${etcd_cfg} /etc/default/etcd
+	fi
     else
 	# Configure an etcd master node.
-	sudo sed -i "s/exec.*/exec \/usr\/bin\/etcd --name=\"$HOSTNAME\" \
+	if test -f /etc/init/etcd.conf; then
+	    # upstart configuration
+	    sudo sed -i "s/exec.*/exec \/usr\/bin\/etcd --name=\"$HOSTNAME\" \
   --advertise-client-urls=\"http:\/\/$IP:2379,http:\/\/$IP:4001\" \
   --listen-client-urls=\"http:\/\/0.0.0.0:2379,http:\/\/0.0.0.0:4001\" \
   --listen-peer-urls \"http:\/\/0.0.0.0:2380\" \
@@ -39,6 +52,21 @@ function install_configure_etcd {
   --initial-cluster-token \"$TOKEN\" \
   --initial-cluster \"$HOSTNAME=http:\/\/$IP:2380\" \
   --initial-cluster-state \"new\"/" /etc/init/etcd.conf
+	else
+	    # systemd configuration
+	    etcd_cfg=`mktemp -t etcd.XXXXXX`
+	    cat >${etcd_cfg} <<EOF
+ETCD_NAME="$HOSTNAME"
+ETCD_ADVERTISE_CLIENT_URLS="http://$IP:2379,http://$IP:4001"
+ETCD_LISTEN_CLIENT_URLS="http://0.0.0.0:2379,http://0.0.0.0:4001"
+ETCD_LISTEN_PEER_URLS="http://0.0.0.0:2380"
+ETCD_INITIAL_ADVERTISE_PEER_URLS="http://$IP:2380"
+ETCD_INITIAL_CLUSTER="$HOSTNAME=http://$IP:2380"
+ETCD_INITIAL_CLUSTER_STATE="new"
+ETCD_INITIAL_CLUSTER_TOKEN="$TOKEN"
+EOF
+	    sudo mv -f ${etcd_cfg} /etc/default/etcd
+	fi
     fi
 
     # Start the etcd service:
@@ -48,7 +76,8 @@ function install_configure_etcd {
 mode=$1				# stack, unstack or clean
 phase=$2			# pre-install, install, post-config or extra
 
-if is_service_enabled calico; then
+if [ "${Q_AGENT}" = calico-felix ]; then
+
     case $mode in
 
 	stack)
@@ -64,7 +93,7 @@ if is_service_enabled calico; then
 		    echo Calico plugin: pre-install
 
 		    # Add Calico PPA as a package source.
-		    sudo apt-add-repository -y ppa:project-calico/kilo-testing
+		    sudo apt-add-repository -y ppa:project-calico/calico-2.0
 		    REPOS_UPDATED=False
 
 		    # Also add BIRD project PPA as a package source.
@@ -89,22 +118,14 @@ if is_service_enabled calico; then
 		    # Install and configure etcd.
 		    install_configure_etcd
 
-		    # Install posix-spawn.
-		    pip_install git+https://github.com/projectcalico/python-posix-spawn.git@1f74fbedb569d4e45f11e9e32d3dca74623f432c#egg=posix-spawn
+		    # Install the Calico agent.
+		    install_package calico-felix
 
-		    # Install the Calico agent (Felix).
-		    FELIX_DIR=${DEST}/felix
-		    git_clone ${FELIX_REPO:-https://github.com/projectcalico/felix.git} $FELIX_DIR ${FELIX_BRANCH:-master}
-		    cd $FELIX_DIR
-		    pip_install .
+		    # Install Calico common code, that includes BIRD templates.
+		    install_package calico-common
 
 		    # Install networking-calico.
-		    pushd ../networking-calico
-		    pip_install .
-		    popd
-
-		    # Also install python-etcd from the Calico project's GitHub.
-		    pip_install -I git+git://github.com/projectcalico/python-etcd.git
+		    pip_install "${GITDIR['networking-calico']}"
 
 		    ;;
 
@@ -148,18 +169,16 @@ EOF
 		    # have been started.
 		    echo Calico plugin: extra
 
-		    # Run Felix and tail its log file.
-		    run_process calico-felix "sudo /usr/local/bin/calico-felix"
-		    tail_log calico-log "/var/log/calico/felix.log"
-
 		    # Run script to automatically generate and
 		    # maintain BIRD config for the cluster.
-		    run_process calico-bird "HOST_IP=$HOST_IP /opt/stack/networking-calico/devstack/auto-bird-conf.sh"
+		    run_process calico-bird \
+                      "sudo ${DEST}/networking-calico/devstack/auto-bird-conf.sh ${HOST_IP}"
 
 		    # Run the Calico DHCP agent.
 		    sudo mkdir /var/log/neutron || true
 		    sudo chown `whoami` /var/log/neutron
-		    run_process calico-dhcp "/usr/local/bin/calico-dhcp-agent --config-file $NEUTRON_CONF"
+		    run_process calico-dhcp \
+		      "/usr/local/bin/calico-dhcp-agent --config-file $NEUTRON_CONF"
 
 		    ;;
 
