@@ -34,14 +34,10 @@ import os
 import eventlet
 from eventlet.semaphore import Semaphore
 from neutron.agent import rpc as agent_rpc
-from neutron.common import constants
-from neutron.common.exceptions import PortNotFound
-from neutron.common.exceptions import SubnetNotFound
 from neutron.common import topics
 from neutron import context as ctx
 from neutron.db import l3_db
 from neutron.db import models_v2
-from neutron import manager
 from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2.drivers import mech_agent
 from sqlalchemy import exc as sa_exc
@@ -49,41 +45,18 @@ from sqlalchemy import exc as sa_exc
 # Monkeypatch import
 import neutron.plugins.ml2.rpc as rpc
 
-# OpenStack imports.
-try:
-    from oslo.config import cfg
-except ImportError:
-    from oslo_config import cfg
-
-try:  # Icehouse, Juno
-    from neutron.openstack.common import log
-except ImportError:  # Kilo
-    from oslo_log import log
-
-try:
-    # Icehouse.
-    from neutron.openstack.common.db import exception as db_exc
-except ImportError:
-    try:
-        # Juno.
-        from oslo.db import exception as db_exc
-    except ImportError:
-        # Later.
-        from oslo_db import exception as db_exc
-
-try:
-    # Icehouse/Juno.
-    from neutron.openstack.common import lockutils
-except ImportError:
-    # Later.
-    from oslo_concurrency import lockutils
-
 # Calico imports.
 import etcd
+from networking_calico.compat import cfg
+from networking_calico.compat import constants
+from networking_calico.compat import db_exc
+from networking_calico.compat import lockutils
+from networking_calico.compat import log
+from networking_calico.compat import n_exc
+from networking_calico.compat import plugin_dir
 from networking_calico import datamodel_v1
 from networking_calico.logutils import logging_exceptions
 from networking_calico.monotonic import monotonic_time
-
 from networking_calico.plugins.ml2.drivers.calico import t_etcd
 
 LOG = log.getLogger(__name__)
@@ -316,7 +289,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             self._epoch += 1
             eventlet.spawn(self.periodic_resync_thread, self._epoch)
             eventlet.spawn(self._status_updating_thread, self._epoch)
-            for _ in xrange(cfg.CONF.calico.num_port_status_threads):
+            for _ in range(cfg.CONF.calico.num_port_status_threads):
                 eventlet.spawn(self._loop_writing_port_statuses, self._epoch)
             LOG.info("Calico mechanism driver initialisation done in process "
                      "%s", current_pid)
@@ -502,7 +475,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
 
     def _get_db(self):
         if not self.db:
-            self.db = manager.NeutronManager.get_plugin()
+            self.db = plugin_dir.get_plugin()
             LOG.info("db = %s" % self.db)
 
             # Update the reference to ourselves.
@@ -551,6 +524,10 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
         if port['device_owner'].startswith('compute:'):
             return True
 
+        # Also return True if port is for a Kuryr container.
+        if port['device_owner'].startswith('kuryr:container'):
+            return True
+
         # Otherwise log and return False.
         LOG.debug("Not a VM port: %s" % port)
         return False
@@ -627,43 +604,8 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
         port = context._port
 
         # Immediately halt processing if this is not an endpoint port.
-        if not self._port_is_endpoint_port(port):
-            return
-
-        # If the port binding VIF type is 'unbound', this port doesn't actually
-        # need to be networked yet. We can simply return immediately.
-        if port['binding:vif_type'] == 'unbound':
-            LOG.info("Creating unbound port: no work required.")
-            return
-
-        plugin_context = context._plugin_context
-        with self._txn_from_context(plugin_context, tag="create-port"):
-            # First, regain the current port. This protects against concurrent
-            # writes breaking our state.
-            port = self.db.get_port(plugin_context, port['id'])
-
-            # Next, fill out other information we need on the port.
-            port = self.add_extra_port_information(
-                plugin_context, port
-            )
-
-            # Next, we need to work out what security profiles apply to this
-            # port and grab information about them.
-            profiles = self.get_security_profiles(
-                plugin_context, port
-            )
-
-            # Write data for those profiles into etcd.
-            for profile in profiles:
-                self.transport.write_profile_to_etcd(profile)
-
-            # Pass this to the transport layer.
-            # Implementation note: we could arguably avoid holding the
-            # transaction for this length and instead release it here, then
-            # use atomic CAS. The problem there is that we potentially have to
-            # repeatedly respin and regain the transaction. Let's not do that
-            # for now, and performance test to see if it's a problem later.
-            self.transport.endpoint_created(port)
+        if self._port_is_endpoint_port(port):
+            self._create_endpoint(context, port)
 
     @retry_on_cluster_id_change
     @requires_state
@@ -681,42 +623,8 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
         original = context.original
 
         # Abort early if we're managing non-endpoint ports.
-        if not self._port_is_endpoint_port(port):
-            return
-
-        # If this port update is purely for a status change, don't do anything:
-        # we don't care about port statuses.
-        if port_status_change(port, original):
-            LOG.info('Called for port status change, no action.')
-            return
-
-        # Now, re-read the port.
-        plugin_context = context._plugin_context
-        with self._txn_from_context(plugin_context, tag="update-port"):
-            port = self.db.get_port(plugin_context, port['id'])
-
-            # Now, fork execution based on the type of update we're performing.
-            # There are a few:
-            # - a port becoming bound (binding vif_type from unbound to bound);
-            # - a port becoming unbound (binding vif_type from bound to
-            #   unbound);
-            # - an Icehouse migration (binding host id changed and port bound);
-            # - an update (port bound at all times);
-            # - a change to an unbound port (which we don't care about, because
-            #   we do nothing with unbound ports).
-            if port_bound(port) and not port_bound(original):
-                self._port_bound_update(context, port)
-            elif port_bound(original) and not port_bound(port):
-                self._port_unbound_update(context, original)
-            elif original['binding:host_id'] != port['binding:host_id']:
-                LOG.info("Icehouse migration")
-                self._icehouse_migration_step(context, port, original)
-            elif port_bound(original) and port_bound(port):
-                LOG.info("Port update")
-                self._update_port(plugin_context, port)
-            else:
-                LOG.info("Update on unbound port: no action")
-                pass
+        if self._port_is_endpoint_port(port):
+            self._update_endpoint(context, port, original)
 
     @retry_on_cluster_id_change
     @requires_state
@@ -812,6 +720,77 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             with context.session.begin(subtransactions=True) as txn:
                 yield txn
 
+    def _create_endpoint(self, context, port):
+        # If the port binding VIF type is 'unbound', this port doesn't actually
+        # need to be networked yet. We can simply return immediately.
+        if port['binding:vif_type'] == 'unbound':
+            LOG.info("Creating unbound port: no work required.")
+            return
+
+        plugin_context = context._plugin_context
+        with self._txn_from_context(plugin_context, tag="create-port"):
+            # First, regain the current port. This protects against concurrent
+            # writes breaking our state.
+            port = self.db.get_port(plugin_context, port['id'])
+
+            # Next, fill out other information we need on the port.
+            port = self.add_extra_port_information(
+                plugin_context, port
+            )
+
+            # Next, we need to work out what security profiles apply to this
+            # port and grab information about them.
+            profiles = self.get_security_profiles(
+                plugin_context, port
+            )
+
+            # Write data for those profiles into etcd.
+            for profile in profiles:
+                self.transport.write_profile_to_etcd(profile)
+
+            # Pass this to the transport layer.
+            # Implementation note: we could arguably avoid holding the
+            # transaction for this length and instead release it here, then
+            # use atomic CAS. The problem there is that we potentially have to
+            # repeatedly respin and regain the transaction. Let's not do that
+            # for now, and performance test to see if it's a problem later.
+            self.transport.endpoint_created(port)
+
+    def _update_endpoint(self, context, port, original):
+        # If this port update is purely for a status change, don't do anything:
+        # we don't care about port statuses.
+        if port_status_change(port, original):
+            LOG.info('Called for port status change, no action.')
+            return
+
+        # Now, re-read the port.
+        plugin_context = context._plugin_context
+        with self._txn_from_context(plugin_context, tag="update-port"):
+            port = self.db.get_port(plugin_context, port['id'])
+
+            # Now, fork execution based on the type of update we're performing.
+            # There are a few:
+            # - a port becoming bound (binding vif_type from unbound to bound);
+            # - a port becoming unbound (binding vif_type from bound to
+            #   unbound);
+            # - an Icehouse migration (binding host id changed and port bound);
+            # - an update (port bound at all times);
+            # - a change to an unbound port (which we don't care about, because
+            #   we do nothing with unbound ports).
+            if port_bound(port) and not port_bound(original):
+                self._port_bound_update(context, port)
+            elif port_bound(original) and not port_bound(port):
+                self._port_unbound_update(context, original)
+            elif original['binding:host_id'] != port['binding:host_id']:
+                LOG.info("Icehouse migration")
+                self._icehouse_migration_step(context, port, original)
+            elif port_bound(original) and port_bound(port):
+                LOG.info("Port update")
+                self._update_port(plugin_context, port)
+            else:
+                LOG.info("Update on unbound port: no action")
+                pass
+
     def _port_unbound_update(self, context, port):
         """_port_unbound_update
 
@@ -1108,7 +1087,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             with self._txn_from_context(context, tag="resync-subnets-changed"):
                 try:
                     neutron_subnet = self.db.get_subnet(context, subnet.id)
-                except SubnetNotFound:
+                except n_exc.SubnetNotFound:
                     # The subnet got deleted.
                     LOG.info("Failed to resync deleted subnet %s", subnet.id)
                     continue
@@ -1266,7 +1245,7 @@ class CalicoMechanismDriver(mech_agent.SimpleAgentMechanismDriverBase):
             with self._txn_from_context(context, tag="resync-ports-changed"):
                 try:
                     port = self.db.get_port(context, endpoint.id)
-                except PortNotFound:
+                except n_exc.PortNotFound:
                     # The endpoint got deleted.
                     LOG.info("Failed to update deleted port %s", endpoint.id)
                     continue
