@@ -20,21 +20,21 @@ import logging
 import mock
 import socket
 
-LOG = logging.getLogger(__name__)
+from neutron.agent.dhcp_agent import register_options
+from neutron.agent.linux import dhcp
+from neutron.tests import base
 
 from networking_calico.agent.dhcp_agent import CalicoDhcpAgent
 from networking_calico.agent.dhcp_agent import FakePlugin
 from networking_calico.agent.dhcp_agent import get_etcd_connection_settings
 from networking_calico.agent.linux.dhcp import DnsmasqRouted
 from networking_calico.common import config as calico_config
+from networking_calico.compat import cfg
+from networking_calico.compat import DHCPV6_STATEFUL
 from networking_calico import datamodel_v1
 from networking_calico.etcdutils import EtcdWatcher
-from neutron.agent.dhcp_agent import register_options
-from neutron.agent.linux import dhcp
-from neutron.common import constants
-from neutron.tests import base
-from oslo_config import cfg
 
+LOG = logging.getLogger(__name__)
 
 EtcdResponse = namedtuple('EtcdResponse', ['value'])
 
@@ -64,6 +64,8 @@ class TestDhcpAgent(base.BaseTestCase):
         super(TestDhcpAgent, self).setUp()
         register_options(cfg.CONF)
         calico_config.register_options(cfg.CONF)
+        self.mock_makedirs_p = mock.patch("os.makedirs")
+        self.mock_makedirs = self.mock_makedirs_p.start()
 
     @mock.patch('etcd.Client')
     def test_mainline(self, etcd_client_cls):
@@ -538,6 +540,8 @@ class TestDnsmasqRouted(base.BaseTestCase):
             'interface_driver',
             'networking_calico.agent.linux.interface.RoutedInterfaceDriver'
         )
+        self.mock_makedirs_p = mock.patch("os.makedirs")
+        self.mock_makedirs = self.mock_makedirs_p.start()
 
     @mock.patch('neutron.agent.linux.dhcp.DeviceManager')
     @mock.patch(commonutils)
@@ -552,8 +556,8 @@ class TestDnsmasqRouted(base.BaseTestCase):
         v6subnet.enable_dhcp = True
         v6subnet.ip_version = 6
         v6subnet.cidr = '2001:db8:1::/80'
-        v6subnet.ipv6_ra_mode = constants.DHCPV6_STATEFUL
-        v6subnet.ipv6_address_mode = constants.DHCPV6_STATEFUL
+        v6subnet.ipv6_ra_mode = DHCPV6_STATEFUL
+        v6subnet.ipv6_address_mode = DHCPV6_STATEFUL
         network = mock.Mock()
         network.id = 'calico'
         network.subnets = [v4subnet, v6subnet]
